Decorators
==========

The core HGraph decorators.

.. autofunction:: hgraph.operator

.. autofunction:: hgraph.graph

.. autofunction:: hgraph.compute_node

.. autofunction:: hgraph.sink_node

.. autofunction:: hgraph.generator

.. autofunction:: hgraph.push_queue

.. autofunction:: hgraph.const_fn

.. autofunction:: hgraph.reference_service

.. autofunction:: hgraph.subscription_service

.. autofunction:: hgraph.request_reply_service

.. autofunction:: hgraph.service_impl

.. autofunction:: hgraph.adaptor

.. autofunction:: hgraph.adaptor_impl

.. autofunction:: hgraph.service_adaptor

.. autofunction:: hgraph.service_adaptor_impl

.. autofunction:: hgraph.component

.. autofunction:: hgraph.pull_source_node

.. autofunction:: hgraph.push_source_node

Supporting functions
--------------------

In order to support the service and adaptor decorators, the following functions are defined:

.. autofunction:: hgraph.register_service

.. autofunction:: hgraph.register_adaptor
